/** @file cfio_io.h
 * This file contains data definitions and prototypes 
 * that define one instance of compact flash interface
 *
 * Copyright  Marvell International Ltd. and/or its affiliates, 2003-2006
 * 
 * This software file (the "File") is owned and distributed by 
 * Marvell International Ltd. and/or its affiliates ("Marvell") 
 * under the terms and conditions of the General Public License 
 * Version 2, June 1991 (the "GPL License"), a copy of which is 
 * available along with the File in the license.txt file or by
 * writing to the Free Software Foundation, Inc., 59 Temple Place, 
 * Suite 330, Boston, MA 02111-1307 or on the worldwide web at 
 * http://www.gnu.org/licenses/gpl.txt. 
 * 
 * THE FILE IS DISTRIBUTED AS-IS, WITHOUT WARRANTY OF ANY KIND, 
 * AND THE IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR 
 * A PARTICULAR PURPOSE ARE EXPRESSLY DISCLAIMED.  The GPL License 
 * provides additional details about this warranty disclaimer.
 * 
 */

/******************************************************
Change log:
	09/29/05: add Doxygen format comments
	1/12/06: Add Kernel 2.6 support
******************************************************/ 

#ifndef _CF_IO_IO_H_
#define _CF_IO_IO_H_

#define EXTERN extern

#include <linux/kernel.h>
#include <linux/module.h>
#include <linux/init.h>
#include <linux/sched.h>
#include <linux/ptrace.h>
#include <linux/slab.h>
#include <linux/string.h>
#include <linux/timer.h>
#include <linux/ioport.h>
#include <linux/module.h> 
#include <asm/io.h>
#include <asm/system.h>
#include <linux/net.h>
#include <asm/irq.h>

#include <linux/netdevice.h>
#include <linux/etherdevice.h>
#include <linux/skbuff.h>
#include <linux/if_arp.h>
#include <linux/ioport.h>
#include <linux/config.h>

#include <pcmcia/version.h>
#include <pcmcia/cs_types.h>
#include <pcmcia/cs.h>
#include <pcmcia/cistpl.h>
#include <pcmcia/cisreg.h>
#include <pcmcia/ds.h>


#define CF_Signature        0xDEADBEEF

/*CF card data structure*/
struct cf_card_rec
{
  struct net_device *eth_dev;
  unsigned long port;
  u16 irq;
  u16 host_int_mask;
  u8  flag;
  u8  reserved[3];
  int do_read_modify_write;
  void *(*add)(struct cf_card_rec *card);
  int   (*remove)(struct cf_card_rec *card);
  void  (*user_isr)(int, void*, struct pt_regs*);
} ;

typedef void *  (*cf_notifier_fn_add) (struct cf_card_rec *);
typedef int (*cf_notifier_fn_remove) (struct cf_card_rec *);

extern dev_info_t cfio_dev_info;
extern dev_link_t *dev_list;

extern struct cf_card_rec cardp;
s16 cfio_read_cfg_reg(void *priv);


#endif  /* _CF_IO_IO_H_ */
