/*
 * Copyright  Marvell International Ltd. and/or its affiliates, 2003-2006
     This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef	_OS_MACROS_H
#define _OS_MACROS_H

#define os_time_get()	jiffies

#ifdef LINUX_2_4
#define OS_INT_DISABLE		cli()
#define OS_INT_RESTORE		sti()
#else
extern spinlock_t	driver_lock;
extern unsigned long	driver_flags;
#define OS_INT_DISABLE	spin_lock_irqsave(&driver_lock, driver_flags)
#define	OS_INT_RESTORE	spin_unlock_irqrestore(&driver_lock, driver_flags); \
			driver_lock = SPIN_LOCK_UNLOCKED
#endif

#define	TX_DISABLE			/* require for threadx */
#define TX_RESTORE			/* require for threadx */
#define	ConfigureThreadPriority()	/* required for threadx */

/* Define these to nothing, these are needed only for threadx */
#define OS_INTERRUPT_SAVE_AREA
#define OS_FREE_LOCK(x)
#define TX_EVENT_FLAGS_SET(x, y, z)

#define UpdateTransStart(dev) { \
	dev->trans_start = jiffies; \
}

#define OS_SET_THREAD_STATE(x)		set_current_state(x)

#ifdef LINUX_2_4
#define MODULE_GET	MOD_INC_USE_COUNT
#define MODULE_PUT	MOD_DEC_USE_COUNT
#else
#define MODULE_GET	try_module_get(THIS_MODULE)
#define MODULE_PUT	module_put(THIS_MODULE)
#endif

static inline void os_sched_timeout(u32 millisec)
{
	set_current_state(TASK_INTERRUPTIBLE);

	schedule_timeout((millisec * HZ) / 1000);
}

static inline void os_schedule(u32 millisec)
{
	schedule_timeout((millisec * HZ) / 1000);
}

static inline int CopyMulticastAddrs(wlan_adapter *Adapter, 
						struct net_device *dev)
{
	int			i = 0;
	struct dev_mc_list	*mcptr = dev->mc_list;
				
	for (i = 0; i < dev->mc_count; i++) {
		memcpy(&Adapter->MulticastList[i], mcptr->dmi_addr, ETH_ALEN);
		mcptr = mcptr->next;
	}


	return i;

}

static inline int os_upload_rx_packet(wlan_private *priv, 
				struct sk_buff *skb)
{

#define IPFIELD_ALIGN_OFFSET	2
	PRINTM(INFO, "skb->data=%p\n", skb->data);

	skb->dev = priv->wlan_dev.netdev;
	skb->protocol = eth_type_trans(skb, priv->wlan_dev.netdev);
	skb->ip_summed = CHECKSUM_UNNECESSARY;

	
	netif_rx(skb);

	return 0;
}

static inline void os_free_tx_packet(wlan_private *priv)
{
	ulong	flags;

	spin_lock_irqsave(&priv->adapter->CurrentTxLock, flags);
	
	if (priv->adapter->CurrentTxSkb) {
		kfree_skb(priv->adapter->CurrentTxSkb);
	}

	priv->adapter->CurrentTxSkb = NULL;
	
	spin_unlock_irqrestore(&priv->adapter->CurrentTxLock, flags);
}

/* netif carrier_on/off and start(wake)/stop_queue handling
		carrier_on	carrier_off	start_queue	stop_queue
 open		x(connect)	x(disconnect)	x
 close				x				x
 assoc		x				x
 adhoc-start	x				x
 adhoc-join	x				x
 scan-begin			x				x
 scan-end	x				x
 deauth				x				x
 ps-sleep			x				x
 ps-awake	x				x
 ds-enter			x				x
 ds-exit	x				x
 xmit								x
 xmit-done					x
 tx-timeout
 */

static inline void os_carrier_on(wlan_private *priv) 
{
	if (!netif_carrier_ok(priv->wlan_dev.netdev) &&
		(priv->adapter->MediaConnectStatus == WlanMediaStateConnected))
		netif_carrier_on(priv->wlan_dev.netdev);
}

static inline void os_carrier_off(wlan_private *priv) 
{
	if (netif_carrier_ok(priv->wlan_dev.netdev))
		netif_carrier_off(priv->wlan_dev.netdev);
}

static inline void os_start_queue(wlan_private *priv) 
{
	if (netif_queue_stopped(priv->wlan_dev.netdev) && 
 		(priv->adapter->MediaConnectStatus == WlanMediaStateConnected)) {
		netif_wake_queue(priv->wlan_dev.netdev);
	}
}

static inline void os_stop_queue(wlan_private *priv) 
{
	if (!netif_queue_stopped(priv->wlan_dev.netdev)) {
		netif_stop_queue(priv->wlan_dev.netdev);
	}
}

#endif /* _OS_MACROS_H */
